@@ -217,7 +217,7 @@ def fvspart(
         if stdout:
             print("{}: ".format(datetime), end="")
 
-        sunrise, sunset = None, None
+        sunrise, sunset = np.nan, np.nan
         nighttime = False
         if "daytime" in part_options:
             if callable(part_options["daytime"]):
@@ -449,10 +449,8 @@ class FVSResult(object):
 
 class FluxpartResult(object):
     def __init__(self, fp_results):
-        if type(fp_results) is str:
-            self.df = pd.read_pickle(fp_results)
-            # with open(fp_results, "rb") as f:
-            #     self.meta = pickle.load(f)
+        if isinstance(fp_results, pd.DataFrame):
+            self.df = fp_results
             return
         index = pd.DatetimeIndex(r.label for r in fp_results)
         df0 = pd.DataFrame(
@@ -587,9 +585,13 @@ class FluxpartResult(object):
         )
 
     def save(self, filename):
+        self.save_pickle(filename)
+
+    def save_csv(self, filename):
+        self.df.to_csv(filename) #, na_rep="NAN")
+
+    def save_pickle(self, filename):
         self.df.to_pickle(filename)
-        # with open(filename, "ab") as f:
-        #     pickle.dump(self.meta, f)
 
 
 def _converter_func(slope, intercept):
